using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Administration;
using Microsoft.SharePoint.Utilities;
namespace AutoSuppression
{
    public class Suppression : SPJobDefinition
    {
        //Constructeur vide ncessaire pour la sralisation
        public Suppression()
        {
        }

        //Constructeur qui sera excut lors de l'enregistrement du job
        public Suppression(string JobName, SPWebApplication WebApplication,
            string TargetSite,string TargetList, string MaxLifeTime)
            : base(JobName, WebApplication, null, SPJobLockType.ContentDatabase)
        {
            this.Title = JobName;
            this.Properties.Add("TargetSite", TargetSite);
            this.Properties.Add("TargetList", TargetList);
            this.Properties.Add("MaxLifeTime", MaxLifeTime);
            
        }
        //Mthode polymorphe que l'on rcrit pour dfinir
        //le corps d'excution du job
        public override void Execute(Guid targetInstanceId)
        {
            //Temps vie max
            int MaxLifeTime = 0;
            //Liste cible par la suppression
            string TargetList = null;
            //Site cibl par la suppression
            string TargetSite = null;
            base.Execute(targetInstanceId);
            try
            {
                //Rcupration des paramtres dfinis dans feature.xml
                MaxLifeTime = Convert.ToInt16(this.Properties["MaxLifeTime"].ToString());
                TargetList = this.Properties["TargetList"].ToString();
                TargetSite = this.Properties["TargetSite"].ToString();
                //On obtient une rfrence de l'application web courante
                SPWebApplication WebApplication = this.Parent as SPWebApplication;
                if (WebApplication != null)
                {           
                    //On pointe sur la DB de contenu
                    SPContentDatabase ContentDb = WebApplication.ContentDatabases[targetInstanceId];
                    //On cre une rfrence vers la liste cible
                    SPList TargetListObject = ContentDb.Sites[TargetSite].RootWeb.Lists[TargetList];
                    //Date calcule en tenant compte de l'heure qui sera
                    //utilise dans la requte CAML
                    string CalculatedDate = SPUtility.CreateISO8601DateTimeFromSystemDateTime(DateTime.Now.AddMinutes(-MaxLifeTime)).ToString();
                                      
                    SPQuery Query = new SPQuery();
                    //Requte
                    Query.Query = "<Where><Lt><FieldRef Name='Created' /><Value Type='DateTime' IncludeTimeValue='TRUE'>" + CalculatedDate + "</Value></Lt></Where>";
                    //On parcourt le rsultat et on supprime les items
                    SPListItemCollection Items = TargetListObject.GetItems(Query);
                    int ItemCount = Items.Count;
                    for (int i = 0; i < ItemCount; i++)
                    {
                        SPListItem Item = Items[0] as SPListItem;
                        Item.Delete();
                    }
                    
                }
                
            }
            catch (FormatException)
            {
                throw new ApplicationException("Nombre de minutes incorrect");
            }
            catch (Exception Ex)
            {
                throw new ApplicationException("Une erreur s'est produite:" + Ex.Message);
            }


        }
    }
}
